Package: rgexf
Type: Package
Encoding: UTF-8
Title: Build, Import, and Export GEXF Graph Files
Version: 0.17.0
Authors@R: c(
  person("George", "Vega Yon", email="g.vegayon@gmail.com", role=c("aut", "cre"),
  comment = c(ORCID = "0000-0002-3171-0844")),
  person("Jorge", "Fábrega Lacoa", role=c("ctb")),
  person("Joshua", "Kunst", role=c("ctb")),
  person("Raphaël", "Velt", role=c("cph"), comment="gexf-js library"),
  person(family="Gephi Consortium", role=c("cph"), comment="GEXF language"),
  person("Cornelius", "Fritz", role = "rev", comment = c(what = "JOSS reviewer")),
  person("Jonathan", "Cardoso Silva", role = "rev", comment = c(what = "JOSS reviewer"))
  )
Description: Create, read, and write 'GEXF' (Graph Exchange 'XML' Format) graph files (used in 'Gephi' and others). Using the 'XML' package, rgexf allows reading and writing GEXF files, including attributes, 'GEXF' visual attributes (such as color, size, and position), network dynamics (for both edges and nodes), and edges' weights. Users can build/handle graphs element-by-element or massively through data frames, visualize the graph on a web browser through 'gexf-js' (a 'javascript' library), and interact with the 'igraph' package.
URL: https://gvegayon.github.io/rgexf/
BugReports: https://github.com/gvegayon/rgexf/issues
Imports: XML, igraph, grDevices, utils, servr, htmlwidgets, jsonlite
License: MIT + file LICENSE
LazyLoad: yes
Suggests: knitr, rmarkdown, tinytest, covr
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-22 23:50:27 UTC; runner
Author: George Vega Yon [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3171-0844>),
  Jorge Fábrega Lacoa [ctb],
  Joshua Kunst [ctb],
  Raphaël Velt [cph] (gexf-js library),
  Gephi Consortium [cph] (GEXF language),
  Cornelius Fritz [rev] (what: JOSS reviewer),
  Jonathan Cardoso Silva [rev] (what: JOSS reviewer)
Maintainer: George Vega Yon <g.vegayon@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-23 10:50:09 UTC
Built: R 4.6.0; ; 2026-07-23 14:33:06 UTC; unix
