# Generated by roxygen2: do not edit by hand

S3method(head,gexf)
S3method(plot,gexf)
S3method(print,gexf)
S3method(summary,gexf)
export(add.edge.spell)
export(add.gexf.edge)
export(add.gexf.node)
export(add.node.spell)
export(check.dpl.edges)
export(checkTimes)
export(edge.list)
export(gexf)
export(gexf.to.igraph)
export(gexf_js_config)
export(gexfjs)
export(gexfjsOutput)
export(igraph.to.gexf)
export(new.gexf.graph)
export(plot_gexfjs)
export(read.gexf)
export(renderGexfjs)
export(renderSigmajs)
export(rm.gexf.edge)
export(rm.gexf.node)
export(sigmajs)
export(sigmajsOutput)
export(switch.edges)
export(write.gexf)
import(htmlwidgets)
importFrom(XML,addChildren)
importFrom(XML,asXMLNode)
importFrom(XML,newXMLDoc)
importFrom(XML,newXMLNamespace)
importFrom(XML,newXMLNode)
importFrom(XML,parseXMLAndAdd)
importFrom(XML,saveXML)
importFrom(XML,xmlAttrs)
importFrom(XML,xmlNode)
importFrom(XML,xmlTreeParse)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colors)
importFrom(grDevices,rgb)
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,get.data.frame)
importFrom(igraph,is.directed)
importFrom(igraph,list.edge.attributes)
importFrom(igraph,list.vertex.attributes)
importFrom(igraph,set.edge.attribute)
importFrom(igraph,set.vertex.attribute)
importFrom(servr,httd)
importFrom(stats,complete.cases)
importFrom(utils,head)
